==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/flows/v1/SequenceChannelStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SequenceChannelStatusFluent<A extends SequenceChannelStatusFluent<A>> extends Fluent<A> {


    public ObjectReference getChannel();
    public A withChannel(ObjectReference channel);
    public Boolean hasChannel();
    
/**
 * This method has been deprecated, please use method buildReady instead.
 * @return The buildable object.
 */
@Deprecated public Condition getReady();
    public Condition buildReady();
    public A withReady(Condition ready);
    public Boolean hasReady();
    public SequenceChannelStatusFluent.ReadyNested<A> withNewReady();
    public SequenceChannelStatusFluent.ReadyNested<A> withNewReadyLike(Condition item);
    public SequenceChannelStatusFluent.ReadyNested<A> editReady();
    public SequenceChannelStatusFluent.ReadyNested<A> editOrNewReady();
    public SequenceChannelStatusFluent.ReadyNested<A> editOrNewReadyLike(Condition item);
    public interface ReadyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceChannelStatusFluent.ReadyNested<N>> {

            public N and();
            public N endReady();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/flows/v1/SequenceChannelStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SequenceChannelStatusFluent<A extends SequenceChannelStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildChannel instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getChannel();
    public ObjectReference buildChannel();
    public A withChannel(ObjectReference channel);
    public Boolean hasChannel();
    public SequenceChannelStatusFluent.ChannelNested<A> withNewChannel();
    public SequenceChannelStatusFluent.ChannelNested<A> withNewChannelLike(ObjectReference item);
    public SequenceChannelStatusFluent.ChannelNested<A> editChannel();
    public SequenceChannelStatusFluent.ChannelNested<A> editOrNewChannel();
    public SequenceChannelStatusFluent.ChannelNested<A> editOrNewChannelLike(ObjectReference item);
    
/**
 * This method has been deprecated, please use method buildReady instead.
 * @return The buildable object.
 */
@Deprecated public Condition getReady();
    public Condition buildReady();
    public A withReady(Condition ready);
    public Boolean hasReady();
    public SequenceChannelStatusFluent.ReadyNested<A> withNewReady();
    public SequenceChannelStatusFluent.ReadyNested<A> withNewReadyLike(Condition item);
    public SequenceChannelStatusFluent.ReadyNested<A> editReady();
    public SequenceChannelStatusFluent.ReadyNested<A> editOrNewReady();
    public SequenceChannelStatusFluent.ReadyNested<A> editOrNewReadyLike(Condition item);
    public interface ChannelNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<SequenceChannelStatusFluent.ChannelNested<N>> {

            public N and();
            public N endChannel();    }


    public interface ReadyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<SequenceChannelStatusFluent.ReadyNested<N>> {

            public N and();
            public N endReady();    }


}
